Small python module for printing with colours

PyPi project page: https://pypi.org/project/inprint


Installation
------------

Simply clone the repository and run the usual setuptools process::

  $> git clone https://github.com/Exelscior/inprint.git && cd inprint
  $> python setup.py {build,install}

